
/*
 * @(#)src/classes/sov/com/ibm/jvm/Trace.java, ras-classes, j9shareddev 1.2
 * ===========================================================================
 * IBM Confidential
 * OCO Source Materials
 *
 * IBM Universal Trace Engine v1.0
 *     Copyright IBM Corp. 1998, 2010.
 *
 * The source code for this program is not published or otherwise divested of
 * its trade secrets, irrespective of what has been deposited with the U.S.
 * Copyright office.
 * ===========================================================================
 */

/*
 *
 * Change activity:
 *
 * Reason  Date   Origin  Description
 * ------  ----   ------  ----------------------------------------------------
 * 075648  080704 kates:  Trace Engine Separation
 * 094077  170805 kilnerm Rework AppTrace mechanism
 *
 * ===========================================================================
 * Module Information:
 *
 * DESCRIPTION: Trace class for JVM trace facility manipulation
 * ===========================================================================
 */

package com.ibm.jvm;

import java.util.*;

/**
 * The <code>Trace</code> class contains methods for controlling trace. It
 * cannot be instantiated.
 * <p>
 *
 * @author IBM Hursley JTC
 * @version 1.00, 08/01/99
 * @since JDK1.2.2
 */

public final class Trace {

	private static boolean initialized;

	public static final String EVENT = "0 ";
	public static final String EXCEPTION = "1 ";
	public static final String ENTRY = "2 ";
	public static final String EXIT = "4 ";
	public static final String EXCEPTION_EXIT = "5 ";

	/**
	 * Initialize the class
	 */
	static {
		initializeTrace();
	}

	/** Don't let anyone instantiate this class */
	private Trace() {
	}

	public static void initializeTrace() {
		String keys[];
		String values[];
		int i, j;
		Properties props = System.getProperties();
		Enumeration p;
		if (!initialized) {
			initialized = true;
			/*
			 * Get the current number of system properties
			 */
			p = props.propertyNames();
			for (i = 0; p.hasMoreElements(); i++) {
				p.nextElement();
			}
			keys = new String[i];
			values = new String[i];

			/*
			 * Obtain all current system properties
			 */
			p = props.propertyNames();
			for (j = 0; (j < i && p.hasMoreElements()); j++) {
				keys[j] = (String) p.nextElement();
				values[j] = props.getProperty(keys[j]);
			}
			initTrace(keys, values);
		}
	}

	/*
	 * Natives
	 */

	// Trace initialization
	private static native void initTrace(String keys[], String values[]);

	// Trace control API
	public static native int set(String cmd);

	public static native void snap();

	public static native void suspend();

	public static native void resume();

	public static native void suspendThis();

	public static native void resumeThis();

	// Application trace registration method
	public synchronized static native int registerApplication(String name,
			String[] templates); /* ibm@94077 */

	// Application trace tracing methods
	public static native void trace(int handle, int traceId);

	public static native void trace(int handle, int traceId, String s1);

	public static native void trace(int handle, int traceId, String s1,
			String s2);

	public static native void trace(int handle, int traceId, String s1,
			String s2, String s3);

	public static native void trace(int handle, int traceId, String s1,
			Object o1);

	public static native void trace(int handle, int traceId, Object o1,
			String s1);

	public static native void trace(int handle, int traceId, String s1, int i1);

	public static native void trace(int handle, int traceId, int i1, String s1);

	public static native void trace(int handle, int traceId, String s1, long l1);

	public static native void trace(int handle, int traceId, long l1, String s1);

	public static native void trace(int handle, int traceId, String s1, byte b1);

	public static native void trace(int handle, int traceId, byte b1, String s1);

	public static native void trace(int handle, int traceId, String s1, char c1);

	public static native void trace(int handle, int traceId, char c1, String s1);

	public static native void trace(int handle, int traceId, String s1, float f1);

	public static native void trace(int handle, int traceId, float f1, String s1);

	public static native void trace(int handle, int traceId, String s1,
			double d1);

	public static native void trace(int handle, int traceId, double d1,
			String s1);

	public static native void trace(int handle, int traceId, Object o1);

	public static native void trace(int handle, int traceId, Object o1,
			Object o2);

	public static native void trace(int handle, int traceId, int i1);

	public static native void trace(int handle, int traceId, int i1, int i2);

	public static native void trace(int handle, int traceId, int i1, int i2,
			int i3);

	public static native void trace(int handle, int traceId, long l1);

	public static native void trace(int handle, int traceId, long l1, long l2);

	public static native void trace(int handle, int traceId, long l1, long l2,
			long i3);

	public static native void trace(int handle, int traceId, byte b1);

	public static native void trace(int handle, int traceId, byte b1, byte b2);

	public static native void trace(int handle, int traceId, byte b1, byte b2,
			byte b3);

	public static native void trace(int handle, int traceId, char c1);

	public static native void trace(int handle, int traceId, char c1, char c2);

	public static native void trace(int handle, int traceId, char c1, char c2,
			char c3);

	public static native void trace(int handle, int traceId, float f1);

	public static native void trace(int handle, int traceId, float f1, float f2);

	public static native void trace(int handle, int traceId, float f1,
			float f2, float f3);

	public static native void trace(int handle, int traceId, double d1);

	public static native void trace(int handle, int traceId, double d1,
			double d2);

	public static native void trace(int handle, int traceId, double d1,
			double d2, double d3);

	public static native void trace(int handle, int traceId, String s1,
			Object o1, String s2);

	public static native void trace(int handle, int traceId, Object o1,
			String s1, Object o2);

	public static native void trace(int handle, int traceId, String s1, int i1,
			String s2);

	public static native void trace(int handle, int traceId, int i1, String s1,
			int i2);

	public static native void trace(int handle, int traceId, String s1,
			long l1, String s2);

	public static native void trace(int handle, int traceId, long l1,
			String s1, long l2);

	public static native void trace(int handle, int traceId, String s1,
			byte b1, String s2);

	public static native void trace(int handle, int traceId, byte b1,
			String s1, byte b2);

	public static native void trace(int handle, int traceId, String s1,
			char c1, String s2);

	public static native void trace(int handle, int traceId, char c1,
			String s1, char c2);

	public static native void trace(int handle, int traceId, String s1,
			float f1, String s2);

	public static native void trace(int handle, int traceId, float f1,
			String s1, float f2);

	public static native void trace(int handle, int traceId, String s1,
			double d1, String s2);

	public static native void trace(int handle, int traceId, double d1,
			String s1, double d2);

	/**
	 * Returns the current time in microseconds. The accuracy of the time
	 * returned depends on the level of support provided by the particular chip
	 * the JVM is running on. In particular the time may not exactly match the
	 * time returned by the system clock, so times from this method should only
	 * be compared with other times returned from this method.
	 *
	 * @return the current time in miscroseconds or 0 if a high-resolution timer
	 *         is not supported on the platform.
	 */
	public static native long getMicros();
}
